# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_check1/check1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cth2_grpc_check1/check1.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cth2_grpc_common/common.proto\"K\n\x11\x43heckpointRequest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\"U\n\x12\x43heckpointResponse\x12\x1f\n\ncheckpoint\x18\x01 \x01(\x0b\x32\x0b.Checkpoint\x12\x1e\n\x06status\x18\x02 \x01(\x0b\x32\x0e.RequestStatus\"\x15\n\x07\x43hainID\x12\n\n\x02id\x18\x01 \x01(\t\"\xc0\x02\n\x10\x43heckRuleRequest\x12&\n\x0f\x63onnectivity_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12\'\n\x0broot_filter\x18\n \x01(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\x0b \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12!\n\x0fparent_event_id\x18\x06 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1d\n\tdirection\x18\x08 \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x08.ChainID\x12\x11\n\tbook_name\x18\x0c \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"O\n\x11\x43heckRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\xb9\x03\n\x18\x43heckSequenceRuleRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x30\n\x14root_message_filters\x18\x0c \x03(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\r \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12&\n\x0f\x63onnectivity_id\x18\x05 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x63heck_order\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x1d\n\tdirection\x18\n \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\x0b \x01(\x0b\x32\x08.ChainID\x12\x31\n\rsilence_check\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tbook_name\x18\x0f \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07\"W\n\x19\x43heckSequenceRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\xa0\x01\n\tPreFilter\x12&\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x16.PreFilter.FieldsEntry\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01J\x04\x08\x01\x10\x02\"\xb0\x02\n\x15NoMessageCheckRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x17\n\x0fmessage_timeout\x18\x02 \x01(\x03\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x1f\n\ncheckpoint\x18\x04 \x01(\x0b\x32\x0b.Checkpoint\x12\x1a\n\x08\x63hain_id\x18\x05 \x01(\x0b\x32\x08.ChainID\x12&\n\x0f\x63onnectivity_id\x18\x06 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\tdirection\x18\t \x01(\x0e\x32\n.Direction\x12\x11\n\tbook_name\x18\n \x01(\t\"T\n\x16NoMessageCheckResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID2\xa2\x02\n\x06\x43heck1\x12=\n\x10\x63reateCheckpoint\x12\x12.CheckpointRequest\x1a\x13.CheckpointResponse\"\x00\x12:\n\x0fsubmitCheckRule\x12\x11.CheckRuleRequest\x1a\x12.CheckRuleResponse\"\x00\x12R\n\x17submitCheckSequenceRule\x12\x19.CheckSequenceRuleRequest\x1a\x1a.CheckSequenceRuleResponse\"\x00\x12I\n\x14submitNoMessageCheck\x12\x16.NoMessageCheckRequest\x1a\x17.NoMessageCheckResponse\"\x00\x42 \n\x1c\x63om.exactpro.th2.check1.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_check1.check1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.exactpro.th2.check1.grpcP\001'
  _PREFILTER_FIELDSENTRY._options = None
  _PREFILTER_FIELDSENTRY._serialized_options = b'8\001'
  _CHECKPOINTREQUEST._serialized_start=94
  _CHECKPOINTREQUEST._serialized_end=169
  _CHECKPOINTRESPONSE._serialized_start=171
  _CHECKPOINTRESPONSE._serialized_end=256
  _CHAINID._serialized_start=258
  _CHAINID._serialized_end=279
  _CHECKRULEREQUEST._serialized_start=282
  _CHECKRULEREQUEST._serialized_end=602
  _CHECKRULERESPONSE._serialized_start=604
  _CHECKRULERESPONSE._serialized_end=683
  _CHECKSEQUENCERULEREQUEST._serialized_start=686
  _CHECKSEQUENCERULEREQUEST._serialized_end=1127
  _CHECKSEQUENCERULERESPONSE._serialized_start=1129
  _CHECKSEQUENCERULERESPONSE._serialized_end=1216
  _PREFILTER._serialized_start=1219
  _PREFILTER._serialized_end=1379
  _PREFILTER_FIELDSENTRY._serialized_start=1314
  _PREFILTER_FIELDSENTRY._serialized_end=1373
  _NOMESSAGECHECKREQUEST._serialized_start=1382
  _NOMESSAGECHECKREQUEST._serialized_end=1686
  _NOMESSAGECHECKRESPONSE._serialized_start=1688
  _NOMESSAGECHECKRESPONSE._serialized_end=1772
  _CHECK1._serialized_start=1775
  _CHECK1._serialized_end=2065
# @@protoc_insertion_point(module_scope)
